Strategies
==========

Strategy
--------
.. autoclass:: poisson_approval.Strategy
    :members:

StrategyTwelve
--------------
.. autoclass:: poisson_approval.StrategyTwelve
    :members:
    :inherited-members:

StrategyThreshold
-----------------
.. autoclass:: poisson_approval.StrategyThreshold
    :members:
    :inherited-members:

StrategyOrdinal
---------------
.. autoclass:: poisson_approval.StrategyOrdinal
    :members:
    :inherited-members:
